#
# spec file for package python-pipreqs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pipreqs
Version:        0.4.13
Release:        1.1
Summary:        Pip requirements generator based on imports in project
License:        Apache-2.0
URL:            https://github.com/bndr/pipreqs
Source:         https://files.pythonhosted.org/packages/source/p/pipreqs/pipreqs-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docopt
Requires:       python-yarg
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module docopt}
BuildRequires:  %{python_module yarg}
# /SECTION
%python_subpackages

%description
Pip requirements.txt generator based on imports in project.

%prep
%setup -q -n pipreqs-%{version}
chmod a-x pipreqs/pipreqs.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pipreqs
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Ignore tests that require network access
%pytest -k 'not (test_get_imports_info or test_ignored_directory or test_init or test_init_overwrite or teset_init_savepath or test_omit_version or test_clean or test_dynamic_version)'

%post
%python_install_alternative pipreqs

%postun
%python_uninstall_alternative pipreqs

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/pipreqs
%{python_sitelib}/pipreqs
%{python_sitelib}/pipreqs-%{version}.dist-info

%changelog
* Mon Jul 10 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.13:
  * Update mapping for python-slugify
  * Update mapping socketio to python-socketio
  * Add mapping for python-constraint
  * Mitigation for dependency confusion (bsc#1212933, CVE-2023-31543)
  * enh: include airflow mapping
  * Mapping Telegram to python-telegram-bot
  * added => and ~= support through the "mode" option
- Don't use greedy globs in %%files.
- Switch to pyproject macros.
- Skip more tests that require network access.
- Drop unneeded Requires on setuptools.
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon May 18 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 0.4.10
  * bugfix: f.close() only required if open succeeded
* Fri Mar  1 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.4.9
